@@ -1,6 +1,6 @@
 from apscheduler.schedulers.background import BackgroundScheduler
 
 def create_schedular_app() -> BackgroundScheduler:
-    schedular = BackgroundScheduler()
+    schedular = BackgroundScheduler() # todo move to custom scheduler class
 
     return schedular
\ No newline at end of file
